@@ -15,6 +15,7 @@ def catch_exceptions_service(service: str, pubsub_subscriber: bool=False, auth_e
     def catch_exceptions(job_func: Callable) -> Callable:
         @functools.wraps(job_func)
         def wrapper(*args, **kwargs):
+            parameters = None
             if pubsub_subscriber:
                 try:
                     job_func_signature = inspect.signature(job_func)
@@ -37,14 +38,13 @@ def catch_exceptions_service(service: str, pubsub_subscriber: bool=False, auth_e
                 except ValueError:
                     pass
                 traceback_str = traceback.format_exc()
-                print(f"{traceback_str}\n{message}")
                 request_id = None
-                import sys
                 try:
                     request_id = current_request_id()
                 except KeyError:
                     pass
-                raise Exception(f"[{request_id}]: {str(e)}").with_traceback(sys.exc_info()[2]) from e
+                print(f"{traceback_str}\n{message} with request id {request_id}")
+                raise e
         return wrapper
     return catch_exceptions
 
