@@ -11,7 +11,7 @@ from arcane.pubsub import Client as PubSubClient
 PUBSUB_ACTIVITY_TRACKING_TOPIC = 'activity-tracker'
 
 
-def send_tracking_information(email: str, service: str, function_name: str, project: str,
+def send_tracking_information(email: str, service: str, function_name: str, origin: str, project: str,
                               pubsub_client: PubSubClient, datastore_client: DatastoreClient) -> None:
     """ Send pubsub message to the tracking cloud function"""
 
@@ -30,6 +30,7 @@ def send_tracking_information(email: str, service: str, function_name: str, proj
              'service': service,
              'timestamp': timestamp,
              'function_name': function_name,
-             'insert_id': insert_id
+             'insert_id': insert_id,
+             'origin': origin
              }
         )
